Documentation
¶
Index ¶
- type Client
- func (c *Client) GetAllDataRefs(fetchSize int) ([]RefInfo, error)
- func (c *Client) GetDataRef(refName string) (any, error)
- func (c *Client) GetDataRefSlice(refName string) ([]any, error)
- func (c *Client) Ping() error
- func (c *Client) SetDataRef(refName string, value any) error
- func (c *Client) SetDataRefSlice(refName string, values []any) error
- type Config
- type GetAllRefsParams
- type GetAllRefsResponse
- type GetRefValueParams
- type GetRefValueResponse
- type GetRefValuesParams
- type GetRefValuesResponse
- type HealthCheckResponse
- type RefInfo
- type SetRefValueBody
- type SetRefValueParams
- type SetRefValueResponse
- type SetRefValuesBody
- type SetRefValuesParams
- type SetRefValuesResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
func (*Client) GetAllDataRefs ¶
Fetch datarefs takkes an optional fetch size and then fetches all the available Data Refs from the server
func (*Client) GetDataRef ¶
Fetch the value of a Data Ref
func (*Client) GetDataRefSlice ¶
Get multiple values (slice) from a Data Ref
func (*Client) Ping ¶
Ping sends a GET request to the health check endpoint and returns an error if the response is not 200 OK
func (*Client) SetDataRef ¶
Set a Data Ref value
type GetAllRefsParams ¶
type GetAllRefsParams struct {
FetchSize int `url:"fetch_size"`
}
type GetAllRefsResponse ¶
type GetRefValueParams ¶
type GetRefValueParams struct {
RefName string `url:"ref_name"`
}
type GetRefValueResponse ¶
type GetRefValuesParams ¶
type GetRefValuesParams struct {
RefName string `url:"ref_name"`
}
type GetRefValuesResponse ¶
type HealthCheckResponse ¶
type SetRefValueBody ¶
type SetRefValueBody struct {
RefValue any `json:"ref_value"`
}
type SetRefValueParams ¶
type SetRefValueParams struct {
RefName string `url:"ref_name"`
}
type SetRefValueResponse ¶
type SetRefValuesBody ¶
type SetRefValuesBody struct {
RefValues []any `json:"ref_values"`
}
type SetRefValuesParams ¶
type SetRefValuesParams struct {
RefName string `url:"ref_name"`
}
Click to show internal directories.
Click to hide internal directories.